@@ -2,6 +2,7 @@ import glob
 import os
 from pathlib import Path
 
+from strictdoc.backend.dsl.errors.document_tree_error import DocumentTreeError
 from strictdoc.backend.source_file_syntax.reader import (
     SourceFileTraceabilityReader,
 )
@@ -11,7 +12,9 @@ from strictdoc.core.finders.source_files_finder import (
     SourceFilesFinder,
     SourceFile,
 )
+from strictdoc.core.source_tree import SourceTree
 from strictdoc.core.traceability_index import TraceabilityIndex
+from strictdoc.core.traceability_index_builder import TraceabilityIndexBuilder
 from strictdoc.export.excel.excel_generator import ExcelGenerator
 from strictdoc.export.html.html_generator import HTMLGenerator
 from strictdoc.export.rst.document_rst_generator import DocumentRSTGenerator
@@ -55,33 +58,39 @@ class ExportAction:
             path_to_single_file_or_doc_root, output_html_root, parallelizer
         )
 
-        traceability_index = TraceabilityIndex.create(document_tree)
+        try:
+            traceability_index: TraceabilityIndex = (
+                TraceabilityIndexBuilder.create(document_tree)
+            )
+        except DocumentTreeError as exc:
+            print(exc.to_print_message())
+            exit(1)
+
         if config.experimental_enable_file_traceability:
-            source_files = SourceFilesFinder.find_source_files(
+            source_tree: SourceTree = SourceFilesFinder.find_source_files(
                 output_html_root, document_tree
             )
-
+            source_files = source_tree.source_files
             source_file: SourceFile
             for source_file in source_files:
                 traceability_reader = SourceFileTraceabilityReader()
                 traceability_info = traceability_reader.read_from_file(
-                    source_file.in_cwd_source_file_rel_path
+                    source_file.full_path
                 )
                 if traceability_info:
                     traceability_index.attach_traceability_info(
                         source_file.in_doctree_source_file_rel_path,
                         traceability_info,
                     )
-            document_tree.attach_source_files(source_files)
+            document_tree.attach_source_tree(source_tree)
 
         if "html" in config.formats or "html-standalone" in config.formats:
             Path(output_html_root).mkdir(parents=True, exist_ok=True)
             HTMLGenerator.export_tree(
-                config.formats,
+                config,
                 document_tree,
                 traceability_index,
                 output_html_root,
-                config.strictdoc_root_path,
                 strictdoc_last_update,
                 asset_dirs,
                 parallelizer,
