@@ -1,6 +1,7 @@
 import collections
 
-from strictdoc.core.document_tree import FileTree, DocumentTree, File
+from strictdoc.core.document_tree import DocumentTree
+from strictdoc.core.file_tree import File, Folder
 
 
 class DocumentTreeIterator:
@@ -9,13 +10,18 @@ class DocumentTreeIterator:
         self.document_tree = document_tree
 
     def iterator(self):
-        task_list = collections.deque(self.document_tree.file_tree)
+        task_list = collections.deque(
+            map(
+                lambda tree: tree.root_folder_or_file,
+                self.document_tree.file_tree,
+            )
+        )
 
         while task_list:
             file_tree_or_file = task_list.popleft()
             if isinstance(file_tree_or_file, File):
                 yield file_tree_or_file
-            elif isinstance(file_tree_or_file, FileTree):
+            elif isinstance(file_tree_or_file, Folder):
                 if not file_tree_or_file.has_sdoc_content:
                     continue
                 yield file_tree_or_file
