@@ -10,9 +10,11 @@ def timing_decorator(name):
             ts = time()
             result = f(*args, **kw)
             te = time()
-            print("Step '{}' took: {} sec".format(name, round(te-ts, 2)))
+            print("Step '{}' took: {} sec".format(name, round(te - ts, 2)))
             return result
+
         return wrap
+
     return timing_internal
 
 
@@ -22,6 +24,6 @@ def measure_performance(title):
     yield
     te = time()
 
-    padded_name = '{title} '.format(title=title).ljust(60, '.')
-    padded_time = ' {:0.2f}'.format((te-ts)).rjust(6, '.')
-    print('{}{}s'.format(padded_name, padded_time))
+    padded_name = "{title} ".format(title=title).ljust(60, ".")
+    padded_time = " {:0.2f}".format((te - ts)).rjust(6, ".")
+    print("{}{}s".format(padded_name, padded_time))
